## TODO - avsecz

  - point to some of the models that were deposited automatically
  - Notes:
	- add the script, ipynb to the root of the repository
      - use Makefile or Snakefile for dumping the models
    - write notes for building the repo to readme.md
    - use `template` directory
	- preventing code duplication:
      - use *relative* soft-links to prevent code duplication
      - use jinja templating
